# Configuration used on VMware guests.

class base::vmguest {
  include base::vmguest::syslog,
          base::vmguest::tripwire

  # Install filter-syslog rules to ignore vmware-tools noise.
  file { '/etc/filter-syslog/vmguest':
    source  => 'puppet:///modules/base/vmguest/etc/filter-syslog/vmguest';
  }

  case $::operatingsystem {
    'debian', 'ubuntu': {
      if $::lsbdistcodename == 'wheezy' {
        package { 'open-vm-dkms': ensure => present }
      } elsif $::lsbdistcodename == 'precise' {
        # Do nothing for now.
      } else {
        package { "open-vm-modules-${::kernelrelease}": ensure => present }
      }
      package { 'open-vm-tools': ensure => present }

      # udev rules for SCSI I/O timeout.  Needs config on older Debian since
      # open-vm-tools doesn't modify udev like VMwareTools on RHEL.
      if $::lsbdistcodename in ['lenny', 'squeeze'] {
        file { '/etc/udev/rules.d/99-vmware-scsi-udev.rules':
          source => 'puppet:///modules/base/vmguest/etc/udev/rules.d/99-vmware-scsi-udev.rules',
        }
      }
    }
    'redhat': {
      package { 'VMwareTools': ensure => present }
      service { 'smartd':
        ensure => stopped,
        enable => false,
      }
    }
  }
}